@@ -19,6 +19,38 @@ my %listOfClassName = ();
 my %overloadedSlots = ();
 my %privateSlots = ();
 my %privateVariableWithPointer = ();
+my $activateSlotPrivatePorting;
+
+sub rewriteConnectPrivateFunction($$$$$$$)
+{
+    if (defined $activateSlotPrivatePorting) {
+      my ($indent, $sender, $signal, $receiver, $slot, $slotArgument, $lastArgument) = @_;
+      my $myNewLine;
+      my $localSlotArgument;
+      my $localSlotVariable;
+      if ($slotArgument eq "()") {
+          $localSlotArgument = "()";
+          $localSlotVariable = "()";
+      } elsif ($slotArgument eq "(QUrl)") {
+          $localSlotArgument = "(const QUrl &url)";
+          $localSlotVariable = "(url)";         
+      } elsif ($slotArgument eq "(KJob*)") {
+          $localSlotArgument = "(KJob *job)";
+          $localSlotVariable = "(job)";         
+      } else {
+         return undef;
+      }
+      if (defined $lastArgument) {
+         # lastArgument has ')'
+         warn "last argument :$lastArgument\n";
+         $myNewLine = $indent . "connect($sender, $signal, $receiver, [this]$localSlotArgument { d->$slot$localSlotVariable; }$lastArgument;\n";
+      } else {
+          $myNewLine = $indent . "connect($sender, $signal, $receiver, [this]$localSlotArgument { d->$slot$localSlotVariable; });\n";
+      }
+      return $myNewLine;
+    }
+    return undef;
+}
 
 sub rewriteConnectFunction($$$$$$)
 {
@@ -529,7 +561,9 @@ foreach my $file (@ARGV) {
                 $sender = cleanSender($sender);
                 my $signalArgument = extraArgumentFunctionName($signal);
                 $signal = extractFunctionName($signal);
+                my $slotArgument = extraArgumentFunctionName($slot);
                 $slot = extractFunctionName($slot);
+                my $originalSlot = $slot;
                 my $localSenderVariable;
                 my $localReceiverVariable;
                 if ( $sender =~ /^&/) {
@@ -542,6 +576,7 @@ foreach my $file (@ARGV) {
                 }
 
                 my $notpossible;
+                my $isPrivateSlot;
                 if ( (defined $varname{$sender}) and (defined $varname{$receiver}) ) {
                     $signal = cast_overloaded_signal($varname{$sender}, $signalArgument, $signal);
                     $slot = "$varname{$receiver}::$slot";
@@ -555,10 +590,17 @@ foreach my $file (@ARGV) {
                         $notpossible = checkOverloadedSlot($slot);
                     }
                     if (not defined $notpossible) {
-                        $notpossible = checkPrivateSlot($slot);
+                        $isPrivateSlot = checkPrivateSlot($slot);
                     }
                     if (not defined $notpossible) {
-                        $_ = rewriteConnectFunction($indent, $sender, $signal, $receiver, $slot, $lastArgument);
+                        if (not defined $isPrivateSlot) {
+                            $_ = rewriteConnectFunction($indent, $sender, $signal, $receiver, $slot, $lastArgument);
+                        } else {
+                            my $localChanges = rewriteConnectPrivateFunction($indent, $sender, $signal, $receiver, $originalSlot, $slotArgument, $lastArgument);
+                            if (defined $localChanges) {
+                                $_ = $localChanges;
+                            }
+                        }
                         undef $toorig;
                     }
                 } else {
@@ -671,7 +713,7 @@ foreach my $file (@ARGV) {
                       $notpossible = checkOverloadedSlot($slot);
                   }
                   if (not defined $notpossible) {
-                      $notpossible = checkPrivateSlot($slot);
+                      $isPrivateSlot = checkPrivateSlot($slot);
                   }
 
                   if (not defined $notpossible) {
@@ -687,7 +729,14 @@ foreach my $file (@ARGV) {
                      if (defined $receiverWithQPointer) {
                          $receiver .= ".data()";
                      }
-                     $_ = rewriteConnectFunction($indent, $sender, $signal, $receiver, $slot, $lastArgument);
+                     if (not defined $isPrivateSlot) {
+                         $_ = rewriteConnectFunction($indent, $sender, $signal, $receiver, $slot, $lastArgument);
+                     } else {
+                         my $localChanges = rewriteConnectPrivateFunction($indent, $sender, $signal, $receiver, $originalSlot, $slotArgument, $lastArgument);
+                         if (defined $localChanges) {
+                            $_ = $localChanges;
+                         }
+                     }
                      undef $toorig;
                   } else {
                        my $line = $_;
@@ -721,8 +770,10 @@ foreach my $file (@ARGV) {
                      $sender = cleanSender($sender);
                      my $signalArgument = extraArgumentFunctionName($signal);
                      $signal = extractFunctionName($signal);
+                     my $slotArgument = extraArgumentFunctionName($slot);
                      $slot = extractFunctionName($slot);
                      my $localVariable;
+                     my $originalSlot = $slot;
                      if ( $sender =~ /^&/) {
                        $sender =~ s/^&//;
                        $localVariable = 1;
@@ -738,6 +789,7 @@ foreach my $file (@ARGV) {
 
                      # => we don't have receiver => slot and signal will have same parent.
                      my $notpossible;
+                     my $isPrivateSlot;
 
                      if ( $headerclassname eq "" ) {
                         $notpossible = "no current classname";
@@ -792,7 +844,7 @@ foreach my $file (@ARGV) {
                           $notpossible = checkOverloadedSlot($slot);
                       }
                       if (not defined $notpossible) {
-                          $notpossible = checkPrivateSlot($slot);
+                          $isPrivateSlot = checkPrivateSlot($slot);
                       }
                       if (not defined $notpossible) {
                         if ( defined $privateClass ) {
@@ -802,7 +854,14 @@ foreach my $file (@ARGV) {
                             $sender = "&" . $sender;
                         }
                         my $receiver = "this";
-                        $_ = rewriteConnectFunction($indent, $sender, $signal, $receiver, $slot, $lastArgument);
+                        if (not defined $isPrivateSlot) {
+                            $_ = rewriteConnectFunction($indent, $sender, $signal, $receiver, $slot, $lastArgument);
+                        } else {
+                            my $localChanges = rewriteConnectPrivateFunction($indent, $sender, $signal, $receiver, $originalSlot, $slotArgument, $lastArgument);
+                            if (defined $localChanges) {
+                                $_ = $localChanges;
+                            }
+                        }
                         undef $toorig;
                       } else {
                          my $line = $_;
