@@ -25,9 +25,24 @@ use List::Util qw(any);
 ### 5. Include '+eV' if you are okay with the KDE e.V. deciding on a future
 ###    licensing change to your code if necessary.
 ###
+### 5. Include 'CCBYSA4+' if you are okay with contributions you've made under
+###    "GNU FDL" being relicensed as "Creative Commons Attribution-ShareAlike 4.0 International".
 ### For more information, see http://techbase.kde.org/Projects/KDE_Relicensing
 
 my %license_table = (
+    'flherne'       => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ],
+    'jriddell'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ],
+    'ltoscano'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ],
+    'lueck'         => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ],
+    'notmart'       => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ],
+    'rkflx'         => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ],
+    'safaalfulaij'  => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ],
+    'sitter'        => ['CCBYSA4'],
+    'sstjames'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ]
+);
+
+my %old_license_table_2 = (
+    # From before CCBYSA4 was added, if you get an update for one of these people move it to %license_table
     'aacid'         => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'abryant'       => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'adawit'        => ['gplv23', 'lgplv23',                      '+eV' ],
@@ -138,7 +153,6 @@ my %license_table = (
     'johnflux'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'jones'         => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'jowenn'        => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
-    'jriddell'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'jschroeder'    => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'jtamate'       => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'kainhofe'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
@@ -154,12 +168,9 @@ my %license_table = (
     'leonhard'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'lilachaze'     => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'lliehu'        => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
-    'ltoscano'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
-    'lueck'         => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'lvsouza'       => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'lypanov'       => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'majewsky'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
-    'maragato '     => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'mardelle'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'martyn'        => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'mbritton'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
@@ -174,7 +185,6 @@ my %license_table = (
     'mludwig'       => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+'        ],
     'mmrozowski'    => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'mpyne'         => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
-    'mrphantom'     => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'mssola'        => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'mueller'       => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+'        ],
     'mwolff'        => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
@@ -185,6 +195,7 @@ my %license_table = (
     'nsams'         => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+'        ],
     'ogoffart'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'orcsik'        => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
+    'palant'        => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'palimaka'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'pdamsten'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+'        ],
     'peifengyu'     => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+'        ],
@@ -248,6 +259,7 @@ my %license_table = (
     'wstephens'     => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'zack'          => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'zecke'         => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ]
+    # Do not add anything here. Use license_table instead.
 );
 
 my %old_license_table = (
@@ -358,31 +370,32 @@ my %old_license_table = (
 );
 
 my %secondary_mail_addresses = (
+    '13thguards@gmail.com' => 'isemenov',
+    'ABBAPOH@me.com' => 'ikomissarov',
+    'aetf@unlimitedcodeworks.xyz' => 'peifengyu',
     'aleixpol@kde.org' => 'apol',
     'asmond@gmx.com' => 'asensi',
-    'aetf@unlimitedcodeworks.xyz' => 'peifengyu',
-    'devel@the-user.org' => 'schmidt-domine',
-    'git@the-user.org' => 'schmidt-domine',
-    'kde@randomguy3.me.uk' => 'alexmerry',
-    'ABBAPOH@me.com' => 'ikomissarov',
-    'tsdgeos@terra.es' => 'aacid',
-    'guy.maurel@kde.org' => 'guymaurel',
-    'sune@vuorela.dk' => 'sune',
-    'christoph@maxiom.de' => 'cfeck',
-    'lamarque@gmail.com' => 'lvsouza',
-    'faure+bluesystems@kde.org' => 'dfaure',
-    'ervin+bluesystems@kde.org' => 'ervin',
-    '13thguards@gmail.com' => 'isemenov',
-    'john@layt.net' => 'jlayt',
-    'richard@goteborg.utfors.se' => 'larkang',
-    'neoclust.kde@free.fr' => 'nlecureuil',
-    'kubito@gmail.com' => 'rkcosta',
     'bero@arklinux.org' => 'bero',
-    'kde@rusu.info' => 'valir',
-    'olav@vitters.nl' => 'vitters',
-    'devriese@kde.org' => 'domi',
     'caleb@gentoo.org' => 'ctennis',
-    'malte@kde.org' => 'malte'
+    'christoph@maxiom.de' => 'cfeck',
+    'devel@the-user.org' => 'schmidt-domine',
+    'devriese@kde.org' => 'domi',
+    'ervin+bluesystems@kde.org' => 'ervin',
+    'faure+bluesystems@kde.org' => 'dfaure',
+    'git@the-user.org' => 'schmidt-domine',
+    'guy.maurel@kde.org' => 'guymaurel',
+    'john@layt.net' => 'jlayt',
+    'kde@randomguy3.me.uk' => 'alexmerry',
+    'kde@rusu.info' => 'valir',
+    'kubito@gmail.com' => 'rkcosta',
+    'lamarque@gmail.com' => 'lvsouza',
+    'malte@kde.org' => 'malte',
+    'neoclust.kde@free.fr' => 'nlecureuil',
+    'olav@vitters.nl' => 'vitters',
+    'richard@goteborg.utfors.se' => 'larkang',
+    'sune@vuorela.dk' => 'sune',
+    'trev@adblockplus.org' => 'palant',
+    'tsdgeos@terra.es' => 'aacid',
 );
 
 my %ruletable;
@@ -395,6 +408,11 @@ foreach my $who (keys %old_license_table) {
     $license_table{$who} = $old_license_table{$who};
 }
 
+foreach my $who (keys %old_license_table_2) {
+    die "$who in both tables" if defined $license_table{$who};
+    $license_table{$who} = $old_license_table_2{$who};
+}
+
 foreach my $who (keys %license_table) {
     foreach my $license(@{$license_table{$who}}) {
         $ruletable{$license}->{$who} = 1;
@@ -512,7 +530,7 @@ parse_arguments(@ARGV);
 if ($generate_wiki) {
 
     print "{| border=\"1\"\n";
-    print "! Name !! GPLv2->GPLv2+ !! LGPLv2 -> LGPLv2+ !! GPLv2 -> GPLv2+v3 !! LGPLv2 -> LGPLv2+LGPLv3 || KDE e.V. decides\n";
+    print "! Name !! GPLv2->GPLv2+ !! LGPLv2 -> LGPLv2+ !! GPLv2 -> GPLv2+v3 !! LGPLv2 -> LGPLv2+LGPLv3 !! KDE e.V. decides !! FDL -> CC-BY-SA 4.0 \n";
     print "|-\n";
     my @lines = ();
     foreach my $who (keys %license_table) {
@@ -528,7 +546,9 @@ if ($generate_wiki) {
         my $lgplv2plus = exists($licensesHash{'lgplv2+'}) ? "YES" : "NO";
         my $eV = exists($licensesHash{'+eV'}) ? "YES" : "NO";
         $eV = "" if (exists $old_license_table{$who});
-        push @lines, "|$authornames{$who} || $gplv2plus || $lgplv2plus || $gplv23 || $lgplv23 || $eV\n";
+        my $ccbysa4 = exists($licensesHash{'CCBYSA4'}) ? "YES" : "NO";
+        $ccbysa4 = "" if (exists $old_license_table_2{$who} || exists $old_license_table{$who});
+        push @lines, "|$authornames{$who} || $gplv2plus || $lgplv2plus || $gplv23 || $lgplv23 || $eV || $ccbysa4\n";
     }
     use locale;
     foreach my $line (sort @lines) {
